Summary
-------

This package contains helper tools allowing a Celery worker running tasks for
a cubicweb-celerytask_ based application to send logging back to the CubicWeb
application.

Please see cubicweb-celerytask_ documentation for more informations on how to
use it.

.. _cubicweb-celerytask: https://www.cubicweb.org/project/cubicweb-celerytask
